@@ -21,7 +21,6 @@ class WebsiteResource(object):
     "filter_unassigned",
     "filter_date_start",
     "filter_date_end",
-    "filter_date_end",
     "order_date_created",
     "order_date_updated",
   ]
@@ -121,6 +120,9 @@ class WebsiteResource(object):
   def send_message_in_conversation(self, website_id, session_id, data):
     return self.parent.post(self.__url_conversation(website_id, session_id, "/message"), data)
 
+  def get_message_in_conversation(self, website_id, session_id, fingerprint):
+    return self.parent.get(self.__url_conversation(website_id, session_id, f"/message/{fingerprint}"))
+
   def update_message_in_conversation(self, website_id, session_id, fingerprint, data):
     return self.parent.patch(self.__url_conversation(website_id, session_id, f"/message/{fingerprint}"), data)
 
@@ -213,6 +215,9 @@ class WebsiteResource(object):
   def save_people_data(self, website_id, people_id, data):
     return self.parent.put(self.__url_people("data", website_id, people_id), data)
 
+  def update_people_data(self, website_id, people_id, data):
+    return self.parent.patch(self.__url_people("data", website_id, people_id), data)
+
   def get_people_subscription_status(self, website_id, people_id):
     return self.parent.get(self.__url_people("subscription", website_id, people_id))
 
